amova for details on the specific implementation.poppr.amova(x, hier = NULL, clonecorrect = FALSE, within = TRUE,
dist = NULL, squared = TRUE, correction = "quasieuclid",
dfname = "population_hierarchy", sep = "_", missing = "loci",
cutoff = 0.05, quiet = FALSE)genind or genclone
objectformula that defines your population
hieararchy. (e.g.: ~Population/Subpopulation). See Details below.logical if TRUE, the data set will be clone
corrected with respect to the lowest level of the hierarchy. The default is
set to FALSE. See clonecorrect for detlogical. When this is set to TRUE (Default),
variance within individuals are calculated as well. If this is set to
FALSE, The lowest level of the hierarchy will be the sample level.
See Details below.character defining the correction method for
non-euclidean distances. Options are quasieuclid
(Default), lingoes, and genind object,
specify the name of the data frame in the other
slot defining the population hierarchy. Defaults to
"populmissingno. Default is
"loci".missingno for details.logical If FALSE (Default), messages regarding any
corrections will be printed to the screen. If TRUE, no messages will
be printed.amova from the ade4 package. See
amova for details.amova class list
that contains the results in the first four elements. The inputs are contained in the
last three elements. The inputs required for the ade4 implementation are:
genind object, but can be daunting for a novice R
user. This function automates the entire process. Since there are many
variables regarding genetic data, some points need to be highlighted: object,
these levels are inherently defined in the hierarchy slot. For
objects, these levels must be defined in a data
frame located within the other slot. It is best
practice to name this data frame "population_hierarchy".}
within = TRUE, poppr will split diploid
genotypes into haplotypes and use those to calculate within-individual
variance. No estimation of phase is made. This acts much like the default
settings for AMOVA in the Arlequin software package. Within individual
variance will not be calculated for haploid individuals or dominant
markers.}
quasieuclid, lingoes, and
cailliez. The correction of these distances should not
adversely affect the outcome of the analysis.}
amova clonecorrect
diss.dist missingno
is.euclid sethierarchydata(Aeut)
agc <- as.genclone(Aeut)
agc
amova.result <- poppr.amova(agc, ~Pop/Subpop)
amova.result
amova.test <- randtest(amova.result) # Test for significance
plot(amova.test)
amova.test
amova.cc.result <- poppr.amova(agc, ~Pop/Subpop, clonecorrect = TRUE)
amova.cc.result
amova.cc.test <- randtest(amova.cc.result)
plot(amova.cc.test)
amova.cc.testRun the code above in your browser using DataLab